@@ -7,6 +7,8 @@ import pytest
 
 from hdx.utilities.loader import load_yaml, load_json, load_and_merge_yaml, load_and_merge_json, LoadError, \
     load_file_to_str, load_yaml_into_existing_dict, load_json_into_existing_dict
+from hdx.utilities.path import temp_dir
+from hdx.utilities.saver import save_str_to_file
 
 
 class TestLoader:
@@ -29,6 +31,19 @@ class TestLoader:
                                  ('dataset', OrderedDict([('required_fields', ['name', 'dataset_date'])])),
                                  ('resource', OrderedDict([('required_fields', ['name', 'description'])])),
                                  ('showcase', OrderedDict([('required_fields', ['name'])])), ('my_param', 'abc')])
+    text = '''  hello
+this
+is
+a
+test  
+
+'''
+    expected_text_strip = '''hello
+this
+is
+a
+test'''
+    expected_text_newlines_to_spaces = '''  hello this is a test    '''
 
     def test_load_empty(self, fixturesfolder):
         loaderfolder = join(fixturesfolder, 'loader')
@@ -60,3 +75,16 @@ class TestLoader:
         result = load_json_into_existing_dict(existing_dict,
                                               join(configfolder, 'project_configuration.json'))
         assert result == TestLoader.expected_json
+
+    def test_load_file_to_str(self):
+        with temp_dir(folder='test_text') as tmpdir:
+            text_file = join(tmpdir, 'text_file.txt')
+            save_str_to_file(TestLoader.text, text_file)
+            result = load_file_to_str(text_file)
+            assert result == TestLoader.text
+            result = load_file_to_str(text_file, strip=True)
+            assert result == TestLoader.expected_text_strip
+            result = load_file_to_str(text_file, replace_newlines=' ')
+            assert result == TestLoader.expected_text_newlines_to_spaces
+            with pytest.raises(IOError):
+                load_file_to_str(join(tmpdir, 'NOTEXIST.txt'))
